"""
    Global constants definition file
"""

import importlib.metadata

VERSION = importlib.metadata.version("tygenie")
ADD_NOTE_SCREEN_NAME = "add_note"
SETTINGS_SCREEN_NAME = "settings"
ALERTS_SCREEN_NAME = "alerts"
