from enum import Enum


class IntegrationType(str, Enum):
    AIRBRAKE = "Airbrake"
    ALERTLOGIC = "AlertLogic"
    ALERTSITE = "AlertSite"
    AMAZONCLOUDTRAIL = "AmazonCloudTrail"
    AMAZONEC2AUTOSCALING = "AmazonEc2AutoScaling"
    AMAZONRDS = "AmazonRds"
    AMAZONROUTE53HEALTHCHECK = "AmazonRoute53HealthCheck"
    AMAZONSECURITYHUB = "AmazonSecurityHub"
    AMAZONSES = "AmazonSes"
    AMAZONSNS = "AmazonSns"
    AMAZONSNSOUTGOING = "AmazonSnsOutgoing"
    API = "API"
    APICA = "Apica"
    APIMETRICS = "Apimetrics"
    APPDYNAMICS = "AppDynamics"
    APPOPTICS = "AppOptics"
    APPSIGNAL = "AppSignal"
    APPSIGNALV2 = "AppSignalV2"
    ATATUS = "Atatus"
    ATLASSIANBAMBOOEMAIL = "AtlassianBambooEmail"
    AUTOTASKAEMEMAIL = "AutotaskAEMEmail"
    AUTOTASKEMAIL = "AutoTaskEmail"
    AZURE = "Azure"
    AZUREAUTOSCALE = "AzureAutoScale"
    AZUREOMS = "AzureOMS"
    AZURERESOURCEHEALTH = "AzureResourceHealth"
    AZURESERVICEHEALTH = "AzureServiceHealth"
    BIGPANDA = "BigPanda"
    BITBUCKET = "Bitbucket"
    BLUEMATADOR = "BlueMatador"
    BMCFOOTPRINTSV11 = "BMCFootPrintsV11"
    BMCFOOTPRINTSV12 = "BMCFootPrintsV12"
    BMCREMEDY = "BMCRemedy"
    BMCREMEDYFORCE = "BMCRemedyForce"
    BMCREMEDYONDEMAND = "BMCRemedyOnDemand"
    BOUNDARY = "Boundary"
    CAMPFIRE = "Campfire"
    CATCHPOINT = "Catchpoint"
    CHECKMK = "CheckMK"
    CHERWELL = "Cherwell"
    CIRCLECI = "CircleCi"
    CIRCONUS = "Circonus"
    CLOUDMONIX = "CloudMonix"
    CLOUDSPLOIT = "CloudSploit"
    CLOUDWATCH = "CloudWatch"
    CLOUDWATCHEVENTS = "CloudWatchEvents"
    CODESHIP = "Codeship"
    COMPOSE = "Compose"
    CONNECTWISE = "ConnectWise"
    CONNECTWISEAUTOMATE = "ConnectWiseAutomate"
    CONNECTWISEMANAGE = "ConnectWiseManage"
    CONNECTWISEMANAGEV2 = "ConnectWiseManageV2"
    CONSUL = "Consul"
    COPPEREGG = "CopperEgg"
    CRASHLYTICS = "Crashlytics"
    DATADOG = "Datadog"
    DATALOOPIO = "DataloopIO"
    DESK = "Desk"
    DETECTIFY = "Detectify"
    DNSCHECK = "DNSCheck"
    DRIPSTAT = "DripStat"
    DYNATRACEAPPMON = "DynatraceAppMon"
    DYNATRACEV2 = "DynatraceV2"
    EMAIL = "Email"
    ERRORCEPTION = "Errorception"
    ESWATCHER = "ESWatcher"
    EVIDENTIO = "EvidentIO"
    FLOCK = "Flock"
    FLOWDOCK = "Flowdock"
    FLOWDOCKV2 = "FlowdockV2"
    FRESHDESK = "Freshdesk"
    FRESHSERVICE = "Freshservice"
    GHOSTINSPECTOR = "GhostInspector"
    GITHUB = "GitHub"
    GITLAB = "GitLab"
    GOOGLESTACKDRIVER = "GoogleStackdriver"
    GRAFANA = "Grafana"
    GRAFANAV2 = "GrafanaV2"
    GRAYLOG = "Graylog"
    HEARTBEAT = "Heartbeat"
    HIPCHAT = "HipChat"
    HIPCHATADDON = "HipChatAddOn"
    HIPCHATV2 = "HipChatV2"
    HONEYBADGER = "Honeybadger"
    HOSTEDGRAPHITE = "HostedGraphite"
    HPSERVICEMANAGER = "HPServiceManager"
    HUMIO = "Humio"
    ICINGA = "Icinga"
    ICINGA2 = "Icinga2"
    INCOMINGCALL = "IncomingCall"
    INSTANA = "Instana"
    JENKINS = "Jenkins"
    JIRA = "Jira"
    JIRASERVICEDESK = "JiraServiceDesk"
    KAPACITOR = "Kapacitor"
    KAYAKO = "Kayako"
    KORE = "Kore"
    LABTECHEMAIL = "LabTechEmail"
    LIBRATO = "Librato"
    LIBRENMS = "LibreNMS"
    LIGHTSTEP = "Lightstep"
    LOGENTRIES = "Logentries"
    LOGGLY = "Loggly"
    LOGICMONITOR = "LogicMonitor"
    LOGSTASH = "Logstash"
    LOGZIO = "LogzIO"
    LOOKER = "Looker"
    LOOM = "Loom"
    MAGENTRIX = "Magentrix"
    MANAGEENGINE = "ManageEngine"
    MARID = "Marid"
    MATTERMOST = "Mattermost"
    MONGODBCLOUD = "MongoDBCloud"
    MONITIS = "Monitis"
    MONITISEMAIL = "MonitisEmail"
    MOXTRA = "Moxtra"
    MSTEAMS = "MSTeams"
    MSTEAMSV2 = "MSTeamsV2"
    NAGIOS = "Nagios"
    NAGIOSV2 = "NagiosV2"
    NAGIOSXI = "NagiosXI"
    NAGIOSXIV2 = "NagiosXIV2"
    NETUITIVE = "Netuitive"
    NEUSTAREMAIL = "NeustarEmail"
    NEWRELIC = "NewRelic"
    NEWRELICV2 = "NewRelicV2"
    NODEPING = "NodePing"
    OBSERVIUM = "Observium"
    OBSERVIUMV2 = "ObserviumV2"
    OEC = "OEC"
    OEM = "OEM"
    OEMEMAIL = "OEMEmail"
    OP5 = "OP5"
    OPSDASH = "OpsDash"
    OPSGENIE = "OpsGenie"
    OPSVIEW = "Opsview"
    PAGERDUTYCOMPATIBILITY = "PagerDutyCompatibility"
    PANOPTA = "Panopta"
    PAPERTRAIL = "Papertrail"
    PINGDOM = "Pingdom"
    PINGDOMV2 = "PingdomV2"
    PINGDOMWEBHOOK = "PingdomWebhook"
    PINGOMETER = "Pingometer"
    PLANIO = "Planio"
    PROMETHEUS = "Prometheus"
    PRTG = "Prtg"
    RACKSPACE = "Rackspace"
    RAYGUN = "Raygun"
    REDGATESQLMONITOREMAIL = "RedGateSqlMonitorEmail"
    RIEMANN = "Riemann"
    RIGOR = "Rigor"
    RINGCENTRALEMAIL = "RingCentralEmail"
    RINGCENTRALGLIP = "RingCentralGlip"
    ROLLBAR = "Rollbar"
    RUNSCOPE = "Runscope"
    RUXIT = "Ruxit"
    SALESFORCESERVICECLOUD = "SalesForceServiceCloud"
    SALTSTACK = "SaltStack"
    SCALYR = "Scalyr"
    SCOM = "SCOM"
    SCOUT = "Scout"
    SEMATEXTSPM = "SematextSpm"
    SENSU = "Sensu"
    SENTRY = "Sentry"
    SERVERDENSITY = "ServerDensity"
    SERVERGUARD24 = "ServerGuard24"
    SERVICENOW = "ServiceNow"
    SERVICENOWV2 = "ServiceNowV2"
    SERVICENOWV3 = "ServiceNowV3"
    SIGNALFX = "Signalfx"
    SIGNALFXV2 = "SignalFXV2"
    SIGNALSCIENCES = "SignalSciences"
    SITE24X7 = "Site24x7"
    SLACK = "Slack"
    SLACKAPP = "SlackApp"
    SOASTA = "Soasta"
    SOLARWINDS = "Solarwinds"
    SOLARWINDSMSPNCENTRAL = "SolarwindsMSPNCentral"
    SOLARWINDSWEBHELPDESK = "SolarWindsWebHelpDesk"
    SPLUNK = "Splunk"
    SPLUNKITSI = "SplunkITSI"
    STACKDRIVER = "Stackdriver"
    STACKSTORM = "StackStorm"
    STATUSCAKE = "StatusCake"
    STATUSHUB = "StatusHub"
    STATUSIO = "StatusIO"
    STATUSPAGEIO = "StatusPageIO"
    STATUSY = "Statusy"
    STRUXUREWARE = "StruxureWare"
    SUMOLOGIC = "SumoLogic"
    SYSDIGCLOUD = "SysdigCloud"
    THOUSANDEYES = "ThousandEyes"
    THREATSTACK = "ThreatStack"
    THUNDRA = "Thundra"
    TIDEWAYS = "Tideways"
    TRACE = "Trace"
    TRACKIT = "TrackIt"
    TRAVISCI = "TravisCI"
    TWILIO = "Twilio"
    UPDOWNIO = "UpdownIO"
    UPTIMEROBOT = "UptimeRobot"
    UPTIMEROBOTEMAIL = "UptimeRobotEmail"
    UPTIMEWEBHOOK = "UptimeWebhook"
    UPTRENDSEMAIL = "UptrendsEmail"
    VCENTER = "VCenter"
    VCSA = "VCSA"
    VIVIDCORTEX = "VividCortex"
    WAVEFRONT = "Wavefront"
    WEBHOOK = "Webhook"
    WHATSUPGOLD = "WhatsUpGold"
    WORKATO = "Workato"
    XLRELEASE = "XLRelease"
    XMPP = "Xmpp"
    ZABBIX = "Zabbix"
    ZAPIER = "Zapier"
    ZENDESK = "Zendesk"
    ZENOSS = "Zenoss"
    ZYRIONEMAIL = "ZyrionEmail"

    def __str__(self) -> str:
        return str(self.value)
